EpubChapter class

Epub chapter object

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EpubChapter({required String title, required String href, required String id, required List<EpubChapter> subitems})
EpubChapter.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
href → String
The href of the chapter, use to navigate to the chapter
final
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subitems → List<EpubChapter>
The subchapters of the chapteri
final
title → String
The title of the chapter
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited