EpubTextExtractRes class

Epub text extraction callback object

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EpubTextExtractRes({String? text, String? cfiRange, String? xpathRange})
EpubTextExtractRes.fromJson(Map<String, dynamic> json)
factory

Properties

cfiRange ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair
xpathRange ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited