clearSelection method
void
clearSelection()
Removes a mark from epub viewer Clears any active text selection in the epub viewer
Implementation
// removeMark({required String cfi}) {
// checkEpubLoaded();
// webViewController?.evaluateJavascript(source: 'removeMark("$cfi")');
// }
///Clears any active text selection in the epub viewer
void clearSelection() {
checkEpubLoaded();
webViewController?.callAsyncJavaScript(functionBody: 'clearSelection()');
}